/*****************************************************************************
 * FVLCPlayer.java FVLC VLC Java RMI Binding
 *****************************************************************************
 *
 * @author : Festastic, <info@festastic.com>
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
 *
 */

package com.festastic.fvlc.rmi;

import java.rmi.Remote;
import java.rmi.RemoteException;

public interface FVLCPlayer extends Remote {

    /**
     * Call play method in JVLC class remotely.
     *
     * @param String
     *            uri
     * @throws RemoteException
     */
    public abstract void play(String uri) throws RemoteException;

    /**
     * Call stop method in JVLC class remotely.
     *
     * @throws RemoteException
     */
    public abstract void stop() throws RemoteException;

    /**
     * Call pause method in JVLC class remotely.
     *
     * @throws RemoteException
     */
    public abstract void togglePause() throws RemoteException;

    /**
     * Call setPosition method in JVLC class remotely.
     *
     * @param float position
     * @throws RemoteException
     */
    public abstract void seek(float position) throws RemoteException;

    /**
     * Call setVolume method in Audio class remotely.
     *
     * @param int volume
     * @throws RemoteException
     */
    public abstract void setVolume(int volume) throws RemoteException;

    /**
     * Call isPlaying method in JVLC class remotely.
     *
     * @return boolean isPlaying
     * @throws RemoteException
     */
    public abstract boolean isPlaying() throws RemoteException;

    /**
     * Call getPosition method in JVLC class remotely.
     *
     * @return float position
     * @throws RemoteException
     */
    public abstract float getPosition() throws RemoteException;

    /**
     * Call cachePosition method in JVLC class remotely.
     *
     * @return boolean isSucceed
     * @throws RemoteException
     */
    public abstract boolean cachePosition() throws RemoteException;

    /**
     * Call System.exit() and exit this process remotely.
     *
     * @throws RemoteException
     */
    public abstract void exit() throws RemoteException;

}